@@ -9,17 +9,13 @@
 #'   [giscoR::gisco_attributions()]
 #'
 #'
-#' @concept political
+#' @family political
 #'
 #' @rdname esp_get_prov
 #' @name esp_get_prov
-
 #'
 #' @return A `sf` object specified by `spatialtype`.
 #'
-#' @seealso
-#' [esp_get_hex_prov()], [esp_get_nuts()], [esp_get_ccaa()],
-#' [esp_get_munic()], [esp_codelist]
 #'
 #' @export
 #'
@@ -234,7 +230,6 @@ esp_get_prov <- function(prov = NULL, ...) {
 #' @rdname esp_get_prov
 #' @name esp_get_prov_siane
 #'
-#' @concept political
 #'
 #' @description
 #' * [esp_get_prov_siane()] uses CartoBase ANE as source, provided by Instituto
@@ -327,7 +322,7 @@ esp_get_prov_siane <- function(prov = NULL,
   data_sf <- merge(data_sf, dfnuts, all.x = TRUE)
 
 
-  # Move CAN
+  # Move can
 
   # Checks
   moving <- FALSE
@@ -346,21 +341,21 @@ esp_get_prov_siane <- function(prov = NULL,
       }
 
       data_sf <- sf::st_transform(data_sf, 3857)
-      PENIN <- data_sf[-grep("05", data_sf$codauto), ]
-      CAN <- data_sf[grep("05", data_sf$codauto), ]
+      penin <- data_sf[-grep("05", data_sf$codauto), ]
+      can <- data_sf[grep("05", data_sf$codauto), ]
 
-      # Move CAN
-      CAN <- sf::st_sf(
-        sf::st_drop_geometry(CAN),
-        geometry = sf::st_geometry(CAN) + offset,
-        crs = sf::st_crs(CAN)
+      # Move can
+      can <- sf::st_sf(
+        sf::st_drop_geometry(can),
+        geometry = sf::st_geometry(can) + offset,
+        crs = sf::st_crs(can)
       )
 
       # Regenerate
-      if (nrow(PENIN) > 0) {
-        data_sf <- rbind(PENIN, CAN)
+      if (nrow(penin) > 0) {
+        data_sf <- rbind(penin, can)
       } else {
-        data_sf <- CAN
+        data_sf <- can
       }
     }
   }
