@@ -1,17 +1,17 @@
 data("esp_munic.sf")
 
-Teruel_cpro <- esp_dict_region_code("Teruel", destination = "cpro")
+teruel_cpro <- esp_dict_region_code("Teruel", destination = "cpro")
 
-Teruel_sf <- esp_munic.sf[esp_munic.sf$cpro == Teruel_cpro, ]
-Teruel_city <- Teruel_sf[Teruel_sf$name == "Teruel", ]
+teruel_sf <- esp_munic.sf[esp_munic.sf$cpro == teruel_cpro, ]
+teruel_city <- teruel_sf[teruel_sf$name == "Teruel", ]
 
 # Plot
 
 library(tmap)
 
-tm_shape(Teruel_sf) +
+tm_shape(teruel_sf) +
   tm_polygons("#FDFBEA") +
-  tm_shape(Teruel_city) +
+  tm_shape(teruel_city) +
   tm_fill(
     col = "name",
     palette = "#C12838",
